==> haskell-dense-linear-algebra-0.1.0.0-41-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-dense-linear-algebra.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 dense-linear-algebra
version:              0.1.0.0
visibility:           public
id:                   dense-linear-algebra-0.1.0.0-E4GDbVH4iUs8b3ZUZRfWtk
key:                  dense-linear-algebra-0.1.0.0-E4GDbVH4iUs8b3ZUZRfWtk
license:              BSD-2-Clause
copyright:            2018 Author name here
maintainer:           Alexey Khudaykov <alexey.skladnoy@gmail.com>
author:               Bryan O'\''Sullivan <bos@serpentine.com>
synopsis:
    Simple and incomplete pure haskell implementation of linear algebra

description:
    This library is simply collection of linear-algebra related modules
    split from statistics library.

category:             Math, Statistics, Numeric
abi:                  b8c0caa3fb131fc07cd51c8942c4c1f2
exposed:              True
exposed-modules:
    Statistics.Matrix Statistics.Matrix.Algorithms
    Statistics.Matrix.Function Statistics.Matrix.Mutable
    Statistics.Matrix.Types

import-dirs:          /usr/lib/ghc-8.8.3/site-local/dense-linear-algebra-0.1.0.0
library-dirs:         /usr/lib/ghc-8.8.3/site-local/dense-linear-algebra-0.1.0.0
dynamic-library-dirs: /usr/lib
data-dir:
    /usr/share/x86_64-linux-ghc-8.8.3/dense-linear-algebra-0.1.0.0

hs-libraries:         HSdense-linear-algebra-0.1.0.0-E4GDbVH4iUs8b3ZUZRfWtk
depends:
    base-4.13.0.0 deepseq-1.4.4.0
    math-functions-0.3.3.0-7POBAsUKUObGnSffbY83ce
    primitive-0.7.0.1-CN4ea3Jrhra6yENuqrDg51
    vector-0.12.1.2-C2W44iPdAFeHo4yLU081Gd
    vector-algorithms-0.8.0.3-5q0FbMM98VU7d7fems8vT5
    vector-binary-instances-0.2.5.1-5AtgwmXON0w4hcU2YWdJ1W
    vector-th-unbox-0.2.1.7-6bqlTl5XJ8ODl2RpTpJBn5

haddock-interfaces:
    /usr/share/doc/haskell-dense-linear-algebra/html/dense-linear-algebra.haddock

haddock-html:         /usr/share/doc/haskell-dense-linear-algebra/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-dense-linear-algebra-0.1.0.0-43-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-dense-linear-algebra.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 dense-linear-algebra
version:              0.1.0.0
visibility:           public
id:                   dense-linear-algebra-0.1.0.0-GS7gp4ceNXoIkGcG4X4WpJ
key:                  dense-linear-algebra-0.1.0.0-GS7gp4ceNXoIkGcG4X4WpJ
license:              BSD-2-Clause
copyright:            2018 Author name here
maintainer:           Alexey Khudaykov <alexey.skladnoy@gmail.com>
author:               Bryan O'\''Sullivan <bos@serpentine.com>
synopsis:
    Simple and incomplete pure haskell implementation of linear algebra

description:
    This library is simply collection of linear-algebra related modules
    split from statistics library.

category:             Math, Statistics, Numeric
abi:                  9851ea1bbcce38a6af99b94017a0650a
exposed:              True
exposed-modules:
    Statistics.Matrix Statistics.Matrix.Algorithms
    Statistics.Matrix.Function Statistics.Matrix.Mutable
    Statistics.Matrix.Types

import-dirs:          /usr/lib/ghc-8.8.3/site-local/dense-linear-algebra-0.1.0.0
library-dirs:         /usr/lib/ghc-8.8.3/site-local/dense-linear-algebra-0.1.0.0
dynamic-library-dirs: /usr/lib
data-dir:
    /usr/share/x86_64-linux-ghc-8.8.3/dense-linear-algebra-0.1.0.0

hs-libraries:         HSdense-linear-algebra-0.1.0.0-GS7gp4ceNXoIkGcG4X4WpJ
depends:
    base-4.13.0.0 deepseq-1.4.4.0
    math-functions-0.3.3.0-D9HamiZAYCYJnENO998fmh
    primitive-0.7.0.1-CN4ea3Jrhra6yENuqrDg51
    vector-0.12.1.2-C2W44iPdAFeHo4yLU081Gd
    vector-algorithms-0.8.0.3-5q0FbMM98VU7d7fems8vT5
    vector-binary-instances-0.2.5.1-5AtgwmXON0w4hcU2YWdJ1W
    vector-th-unbox-0.2.1.7-6bqlTl5XJ8ODl2RpTpJBn5

haddock-interfaces:
    /usr/share/doc/haskell-dense-linear-algebra/html/dense-linear-algebra.haddock

haddock-html:         /usr/share/doc/haskell-dense-linear-algebra/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
